==> com.liferay.layout.content.page.editor.web-1.0.20.jar: META-INF/resources/js/components/sidebar/fragments/FragmentsEditorSidebarCard.es.js <==
"use strict";

Liferay.Loader.define("layout-content-page-editor-web@1.0.20/js/components/sidebar/fragments/FragmentsEditorSidebarCard.es", ['module', 'exports', 'require', 'frontend-js-metal-web$metal-component', 'frontend-js-metal-web$metal-soy', '../../../store/ConnectedComponent.es', './FragmentsEditorSidebarCard.soy'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports.default = exports.FragmentsEditorSidebarCard = exports.ConnectedFragmentsEditorSidebarCard = void 0;

  var _metalComponent = _interopRequireDefault(require("frontend-js-metal-web$metal-component"));

  var _metalSoy = _interopRequireDefault(require("frontend-js-metal-web$metal-soy"));

  var _ConnectedComponent = require("../../../store/ConnectedComponent.es");

  var _FragmentsEditorSidebarCard = _interopRequireDefault(require("./FragmentsEditorSidebarCard.soy"));

  function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : { default: obj };
  }

  function _typeof(obj) {
    if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
      _typeof = function _typeof(obj) {
        return typeof obj;
      };
    } else {
      _typeof = function _typeof(obj) {
        return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
      };
    }return _typeof(obj);
  }

  function _classCallCheck(instance, Constructor) {
    if (!(instance instanceof Constructor)) {
      throw new TypeError("Cannot call a class as a function");
    }
  }

  function _defineProperties(target, props) {
    for (var i = 0; i < props.length; i++) {
      var descriptor = props[i];descriptor.enumerable = descriptor.enumerable || false;descriptor.configurable = true;if ("value" in descriptor) descriptor.writable = true;Object.defineProperty(target, descriptor.key, descriptor);
    }
  }

  function _createClass(Constructor, protoProps, staticProps) {
    if (protoProps) _defineProperties(Constructor.prototype, protoProps);if (staticProps) _defineProperties(Constructor, staticProps);return Constructor;
  }

  function _possibleConstructorReturn(self, call) {
    if (call && (_typeof(call) === "object" || typeof call === "function")) {
      return call;
    }return _assertThisInitialized(self);
  }

  function _assertThisInitialized(self) {
    if (self === void 0) {
      throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
    }return self;
  }

  function _getPrototypeOf(o) {
    _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) {
      return o.__proto__ || Object.getPrototypeOf(o);
    };return _getPrototypeOf(o);
  }

  function _inherits(subClass, superClass) {
    if (typeof superClass !== "function" && superClass !== null) {
      throw new TypeError("Super expression must either be null or a function");
    }subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } });if (superClass) _setPrototypeOf(subClass, superClass);
  }

  function _setPrototypeOf(o, p) {
    _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) {
      o.__proto__ = p;return o;
    };return _setPrototypeOf(o, p);
  }

  /**
   * FragmentsEditorSidebarCard
   * @review
   */
  var FragmentsEditorSidebarCard =
  /*#__PURE__*/
  function (_Component) {
    _inherits(FragmentsEditorSidebarCard, _Component);

    function FragmentsEditorSidebarCard() {
      _classCallCheck(this, FragmentsEditorSidebarCard);

      return _possibleConstructorReturn(this, _getPrototypeOf(FragmentsEditorSidebarCard).apply(this, arguments));
    }

    _createClass(FragmentsEditorSidebarCard, [{
      key: "_handleClick",

      /**
       * Callback that is executed when a item entry is clicked.
       * It propagates a itemClick event with the item information.
       * @param {!MouseEvent} event
       * @private
       * @review
       */
      value: function _handleClick(event) {
        var _event$delegateTarget = event.delegateTarget.dataset,
            itemId = _event$delegateTarget.itemId,
            itemName = _event$delegateTarget.itemName;
        this.emit('itemClick', {
          itemId: itemId,
          itemName: itemName
        });
      }
    }]);

    return FragmentsEditorSidebarCard;
  }(_metalComponent.default);

  exports.FragmentsEditorSidebarCard = FragmentsEditorSidebarCard;
  var ConnectedFragmentsEditorSidebarCard = (0, _ConnectedComponent.getConnectedComponent)(FragmentsEditorSidebarCard, ['spritemap']);
  exports.ConnectedFragmentsEditorSidebarCard = ConnectedFragmentsEditorSidebarCard;

  _metalSoy.default.register(ConnectedFragmentsEditorSidebarCard, _FragmentsEditorSidebarCard.default);

  var _default = ConnectedFragmentsEditorSidebarCard;
  exports.default = _default;
  //# sourceMappingURL=FragmentsEditorSidebarCard.es.js.map
});
//# sourceMappingURL=FragmentsEditorSidebarCard.es.js.map

==> com.liferay.layout.content.page.editor.web-1.0.52.jar: META-INF/resources/js/components/sidebar/fragments/FragmentsEditorSidebarCard.es.js <==
Liferay.Loader.define("layout-content-page-editor-web@1.0.52/js/components/sidebar/fragments/FragmentsEditorSidebarCard.es", ['module', 'exports', 'require', 'frontend-js-metal-web$metal-component', 'frontend-js-metal-web$metal-soy', '../../../store/ConnectedComponent.es', './FragmentsEditorSidebarCard.soy'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports["default"] = exports.FragmentsEditorSidebarCard = exports.ConnectedFragmentsEditorSidebarCard = void 0;

  var _metalComponent = _interopRequireDefault(require("frontend-js-metal-web$metal-component"));

  var _metalSoy = _interopRequireDefault(require("frontend-js-metal-web$metal-soy"));

  var _ConnectedComponent = require("../../../store/ConnectedComponent.es");

  var _FragmentsEditorSidebarCard = _interopRequireDefault(require("./FragmentsEditorSidebarCard.soy"));

  function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : { "default": obj };
  }

  function _typeof(obj) {
    if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
      _typeof = function _typeof(obj) {
        return typeof obj;
      };
    } else {
      _typeof = function _typeof(obj) {
        return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
      };
    }return _typeof(obj);
  }

  function _classCallCheck(instance, Constructor) {
    if (!(instance instanceof Constructor)) {
      throw new TypeError("Cannot call a class as a function");
    }
  }

  function _defineProperties(target, props) {
    for (var i = 0; i < props.length; i++) {
      var descriptor = props[i];descriptor.enumerable = descriptor.enumerable || false;descriptor.configurable = true;if ("value" in descriptor) descriptor.writable = true;Object.defineProperty(target, descriptor.key, descriptor);
    }
  }

  function _createClass(Constructor, protoProps, staticProps) {
    if (protoProps) _defineProperties(Constructor.prototype, protoProps);if (staticProps) _defineProperties(Constructor, staticProps);return Constructor;
  }

  function _possibleConstructorReturn(self, call) {
    if (call && (_typeof(call) === "object" || typeof call === "function")) {
      return call;
    }return _assertThisInitialized(self);
  }

  function _assertThisInitialized(self) {
    if (self === void 0) {
      throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
    }return self;
  }

  function _getPrototypeOf(o) {
    _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) {
      return o.__proto__ || Object.getPrototypeOf(o);
    };return _getPrototypeOf(o);
  }

  function _inherits(subClass, superClass) {
    if (typeof superClass !== "function" && superClass !== null) {
      throw new TypeError("Super expression must either be null or a function");
    }subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } });if (superClass) _setPrototypeOf(subClass, superClass);
  }

  function _setPrototypeOf(o, p) {
    _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) {
      o.__proto__ = p;return o;
    };return _setPrototypeOf(o, p);
  }

  /**
   * FragmentsEditorSidebarCard
   * @review
   */
  var FragmentsEditorSidebarCard =
  /*#__PURE__*/
  function (_Component) {
    _inherits(FragmentsEditorSidebarCard, _Component);

    function FragmentsEditorSidebarCard() {
      _classCallCheck(this, FragmentsEditorSidebarCard);

      return _possibleConstructorReturn(this, _getPrototypeOf(FragmentsEditorSidebarCard).apply(this, arguments));
    }

    _createClass(FragmentsEditorSidebarCard, [{
      key: "_handleClick",

      /**
       * Callback that is executed when a item entry is clicked.
       * It propagates a itemClick event with the item information.
       * @param {!MouseEvent} event
       * @private
       * @review
       */
      value: function _handleClick(event) {
        var _event$delegateTarget = event.delegateTarget.dataset,
            itemGroupId = _event$delegateTarget.itemGroupId,
            itemId = _event$delegateTarget.itemId,
            itemName = _event$delegateTarget.itemName;
        this.emit('itemClick', {
          itemGroupId: itemGroupId,
          itemId: itemId,
          itemName: itemName
        });
      }
    }]);

    return FragmentsEditorSidebarCard;
  }(_metalComponent["default"]);

  exports.FragmentsEditorSidebarCard = FragmentsEditorSidebarCard;
  var ConnectedFragmentsEditorSidebarCard = (0, _ConnectedComponent.getConnectedComponent)(FragmentsEditorSidebarCard, ['spritemap']);
  exports.ConnectedFragmentsEditorSidebarCard = ConnectedFragmentsEditorSidebarCard;

  _metalSoy["default"].register(ConnectedFragmentsEditorSidebarCard, _FragmentsEditorSidebarCard["default"]);

  var _default = ConnectedFragmentsEditorSidebarCard;
  exports["default"] = _default;
  //# sourceMappingURL=FragmentsEditorSidebarCard.es.js.map
});
//# sourceMappingURL=FragmentsEditorSidebarCard.es.js.map
